package server

import (
	"fmt"
	"net/http"

	"github.com/google/uuid"
	"github.com/labstack/echo/v4"
	"github.com/pressly/goose/v3"
)

func (h *Handler) clearDatabase(c echo.Context) error {
	if err := goose.Reset(h.Service.DB, "schema"); err != nil {
		return echo.NewHTTPError(http.StatusInternalServerError, err)
	}

	if err := goose.Up(h.Service.DB, "schema"); err != nil {
		return echo.NewHTTPError(http.StatusInternalServerError, err)
	}

	return nil
}

func (h *Handler) deleteBudget(c echo.Context) error {
	budgetID := c.Param("budgetid")
	budgetUUID, err := uuid.Parse(budgetID)
	if err != nil {
		return echo.NewHTTPError(http.StatusBadRequest, err)
	}

	err = h.clearBudgetData(c, budgetUUID)
	if err != nil {
		return err
	}

	err = h.Service.DeleteBudget(c.Request().Context(), budgetUUID)
	if err != nil {
		return err
	}

	return nil
}

func (h *Handler) clearBudgetData(c echo.Context, budgetUUID uuid.UUID) error {
	rows, err := h.Service.DeleteAllAssignments(c.Request().Context(), budgetUUID)
	if err != nil {
		return err
	}

	fmt.Printf("Deleted %d assignments\n", rows)

	rows, err = h.Service.DeleteAllTransactions(c.Request().Context(), budgetUUID)
	if err != nil {
		return err
	}

	fmt.Printf("Deleted %d transactions\n", rows)
	return nil
}

func (h *Handler) clearBudget(c echo.Context) error {
	budgetID := c.Param("budgetid")
	budgetUUID, err := uuid.Parse(budgetID)
	if err != nil {
		return echo.NewHTTPError(http.StatusBadRequest, err)
	}

	return h.clearBudgetData(c, budgetUUID)
}
